# IncidentType

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**autorun** | **bool** |  | [optional] 
**closure_script** | **str** |  | [optional] 
**color** | **str** |  | [optional] 
**commit_message** | **str** |  | [optional] 
**days** | **int** |  | [optional] 
**days_r** | **int** |  | [optional] 
**default** | **bool** |  | [optional] 
**disabled** | **bool** |  | [optional] 
**hours** | **int** |  | [optional] 
**hours_r** | **int** |  | [optional] 
**id** | **str** |  | [optional] 
**locked** | **bool** |  | [optional] 
**modified** | **datetime** |  | [optional] 
**name** | **str** |  | [optional] 
**playbook_id** | **str** |  | [optional] 
**pre_processing_script** | **str** |  | [optional] 
**prev_name** | **str** |  | [optional] 
**readonly** | **bool** |  | [optional] 
**reputation_calc** | [**ReputationCalcAlg**](ReputationCalcAlg.md) |  | [optional] 
**should_commit** | **bool** |  | [optional] 
**sla** | **int** |  | [optional] 
**sla_reminder** | **int** |  | [optional] 
**sort_values** | **list[str]** |  | [optional] 
**system** | **bool** |  | [optional] 
**vc_should_ignore** | **bool** |  | [optional] 
**version** | **int** |  | [optional] 
**weeks** | **int** |  | [optional] 
**weeks_r** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


